;;;
;;; This program is free software; you can redistribute it and/or modify
;;; it under the terms of the GNU General Public License as published by
;;; the Free Software Foundation; either version 2 of the License, or
;;; (at your option) any later version.
;;;
;;; This program is distributed in the hope that it will be useful,
;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;;; GNU Library General Public License for more details.
;;;
;;; You should have received a copy of the GNU General Public License
;;; along with this program; if not, write to the Free Software
;;; Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

;; from PY.el, GB-18030 
(define py-rule
  '(((("a")) ("" "" "" "" "" "" "߹"))
    ((("a" "i")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("a" "n")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("a" "n" "g")) ("" "" ""))
    ((("a" "o")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("b" "a")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("b" "a" "i")) ("" "" "" "" "" "" "" "" "" "" "" ""))
    ((("b" "a" "n")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("b" "a" "n" "g")) ("" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("b" "a" "o")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("b" "e" "i")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("b" "e" "n")) ("" "" "" "" "" "" "" "" ""))
    ((("b" "e" "n" "g")) ("" "" "" "" "" "" "" "" ""))
    ((("b" "i")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "ذ" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "޵" "" "" "" "" "" "" "" "" "" "" "" "" "ݩ" "" "" "" "" "" "" ""))
    ((("b" "i" "a" "n")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("b" "i" "a" "o")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("b" "i" "e")) ("" "" "" "" ""))
    ((("b" "i" "n")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "")) 
    ((("b" "i" "n" "g")) ("" "" "" "" "" "" "" "" "" "" "" "")) 
    ((("b" "o")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("b" "u")) ("" "" "" "" "" "" "" "" "" "" "" "߲" "" "" "" "" "" "" ""))
    ((("c" "a")) ("" "" ""))
    ((("c" "a" "i")) ("" "" "" "" "" "" "" "" "" "" ""))
    ((("c" "a" "n")) ("" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("c" "a" "n" "g")) ("" "" "" "" "" "")) 
    ((("c" "a" "o")) ("" "" "" "" "" "" "" "" "")) ((("c" "e")) ("" "" "" "" "" ""))
    ((("c" "e" "n")) ("" "" ""))
    ((("c" "e" "n" "g")) ("" "" "" ""))
    ((("c" "h" "a")) ("" "" "" "" "" "ɲ" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("c" "h" "a" "i")) ("" "" "" "" "" "٭" "" ""))
    ((("c" "h" "a" "n")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("c" "h" "a" "n" "g")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("c" "h" "a" "o")) ("" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("c" "h" "e")) ("" "" "" "" "" "" "" ""))
    ((("c" "h" "e" "n")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("c" "h" "e" "n" "g")) ("" "" "" "" "" "" "ʢ" "" "" "" "" "" "" "" "" "" "" "" "ة" "" "" "" "" "" "" "" "" ""))
    ((("c" "h" "i")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "߳" "" "" "" "" "" "" "ܯ" "" "" "" "" "" "" "" "" ""))
    ((("c" "h" "o" "n" "g")) ("" "" "" "" "" "" "" "" "" "" "" ""))
    ((("c" "h" "o" "u")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "ٱ" "" ""))
    ((("c" "h" "u")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "ۻ" "" "" "" "ء" ""))
    ((("c" "h" "u" "a" "i")) ("" "" "" "" "" ""))
    ((("c" "h" "u" "a" "n")) ("" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("c" "h" "u" "a" "n" "g")) ("" "" "" "" "" "" ""))
    ((("c" "h" "u" "i")) ("" "" "" "" "" "" "" "")) 
    ((("c" "h" "u" "n")) ("" "" "" "" "" "" "" "" "" "ݻ"))
    ((("c" "h" "u" "o")) ("" "" "" "" "" ""))
    ((("c" "i")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("c" "o" "n" "g")) ("" "" "" "" "" "" "" "" "" "" "" ""))
    ((("c" "o" "u")) ("" "" "" ""))
    ((("c" "u")) ("" "" "" "" "" "" "" "" "" "" "" "")) 
    ((("c" "u" "a" "n")) ("" "" "" "" "ߥ" "" "" ""))
    ((("c" "u" "i")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("c" "u" "n")) ("" "" "" "" ""))
    ((("c" "u" "o")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("d" "a")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("d" "a" "i")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "߾" "" "" "ܤ" "߰"))
    ((("d" "a" "n")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "")) ((("d" "a" "n" "g")) ("" "" "" "" "" "" "" "" "" "" "" ""))
    ((("d" "a" "o")) ("" "" "" "" "" "" "" "" "" "" "" "߶" "" "" "" "" ""))
    ((("d" "e")) ("" "" "" ""))
    ((("d" "e" "n" "g")) ("" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("d" "i")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "ڮ" "" "" "ۡ" "" "" "" "" "" "" "ݶ" "" "" "" "" "" "ص" "" "" "" ""))
    ((("d" "i" "a")) (""))
    ((("d" "i" "a" "n")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "ؼ"))
    ((("d" "i" "a" "o")) ("" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("d" "i" "e")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "ܦ" "" "" "" ""))
    ((("d" "i" "n" "g")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("d" "i" "u")) ("" ""))
    ((("d" "o" "n" "g")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("d" "o" "u")) ("" "" "" "" "" "" "" "" "" "" "" ""))
    ((("d" "u")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "ܶ" ""))
    ((("d" "u" "a" "n")) ("" "" "" "" "" "" "" "" ""))
    ((("d" "u" "i")) ("" "" "" "" "" "" "" ""))
    ((("d" "u" "n")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("d" "u" "o")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("e")) ("" "" "" "" "Ŷ" "" "" "" "" "ج" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "ݭ"))
    ((("e" "i")) (""))
    ((("e" "n")) ("" "" ""))
    ((("e" "r")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "٦"))
    ((("f" "a")) ("" "" "" "" "" "" "" "" "" ""))
    ((("f" "a" "n")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "ެ" "" "" "" "" ""))
    ((("f" "a" "n" "g")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("f" "e" "i")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("f" "e" "n")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("f" "e" "n" "g")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "ٺ" "" "" "ۺ" "" ""))
    ((("f" "o")) (""))
    ((("f" "o" "u")) ("" ""))
    ((("f" "u")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "ܽ" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "ݳ" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "߻" "" "ۮ" "" "" "" "" "" "" ""))
    ((("g" "a")) ("" "" "" "" "" "٤" "" "" "" ""))
    ((("g" "a" "i")) ("" "" "" "" "ؤ" "" "" "" "" "" ""))
    ((("g" "a" "n")) ("" "" "" "" "" "" "" "" "" "" "" "" "ߦ" "" "" "" "" "" "" "" "" "" "" ""))
    ((("g" "a" "n" "g")) ("" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("g" "a" "o")) ("" "" "" "" "" "" "" "" "غ" "" "޻" "" "" "" "ھ" "" "" "۬" ""))
    ((("g" "e")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "ت" "ܪ" "" "" "" "" "" ""))
    ((("g" "e" "i")) (""))
    ((("g" "e" "n")) ("" "" "ب" "" "" "ݢ"))
    ((("g" "e" "n" "g")) ("" "" "" "" "" "" "" "" "" "" "" ""))
    ((("g" "o" "n" "g")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("g" "o" "u")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "ڸ" "" "" "" "" "" "" ""))
    ((("g" "u")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "ڬ" "" "" "" "" "" ""))
    ((("g" "u" "a")) ("" "" "" "" "" "" "" "" "" "" "" "ڴ"))
    ((("g" "u" "a" "i")) ("" "" "" ""))
    ((("g" "u" "a" "n")) ("" "" "" "" "" "" "" "" "" "" "" "ݸ" "" "" "" "" "" "" ""))
    ((("g" "u" "a" "n" "g")) ("" "" "" "" "" "" ""))
    ((("g" "u" "i")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "Ȳ" "" "" "" ""))
    ((("g" "u" "n")) ("" "" "" "" "" "" ""))
    ((("g" "u" "o")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "")) 
    ((("h" "a")) ("" "" ""))
    ((("h" "a" "i")) ("" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("h" "a" "n")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("h" "a" "n" "g")) ("" "" "" "" "" "" "" "" ""))
    ((("h" "a" "o")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "޶" "" "" ""))
    ((("h" "e")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "ڭ" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("h" "e" "i")) ("" "" ""))
    ((("h" "e" "n")) ("" "" "" ""))
    ((("h" "e" "n" "g")) ("" "" "" "" "" "޿" "" ""))
    ((("h" "o" "n" "g")) ("" "" "" "" "" "" "" "" "" "" "" "ް" "ڧ" "ޮ" "" "" "ݦ"))
    ((("h" "o" "u")) ("" "" "" "" "" "" "" "" "" "" "" "ܩ" "" "" ""))
    ((("h" "u")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("h" "u" "a")) ("" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("h" "u" "a" "i")) ("" "" "" "" "" ""))
    ((("h" "u" "a" "n")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "ۼ" "" "" "" "" "ۨ" "" "" "" "ߧ" "" "" "" ""))
    ((("h" "u" "a" "n" "g")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("h" "u" "i")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "ڶ" "" "" "" "" "" "" "" "" "" "" "" "" "ޥ" "" "" "" "" "" "" "" ""))
    ((("h" "u" "n")) ("" "" "" "" "" "" "" "ڻ" "" "" "")) 
    ((("h" "u" "o")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "߫" "޽" "" "" ""))
    ((("j" "i")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "ߴ" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "ؽ" "ڵ" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "٥" "" "ܸ" "آ" "" "ު" "" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("j" "i" "a")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "ٮ" "Ю" "" "" "" "" "" "" "" "٤" "" "" "" "" "" "" "" "" "" "ۣ" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("j" "i" "a" "n")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("j" "i" "a" "n" "g")) ("" "" "ǿ" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("j" "i" "a" "o")) ("" "" "" "У" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "ٮ" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "ܴ" "" "" "" ""))
    ((("j" "i" "e")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "ڵ" "" "" "" "" "ڦ" "" "" "" "" "" "" "" ""))
    ((("j" "i" "n")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "ݣ" "" "" "" "" ""))
    ((("j" "i" "n" "g")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "ݼ" "" "" "" "" "" "" ""))
    ((("j" "i" "o" "n" "g")) ("" "" "" "" ""))
    ((("j" "i" "u")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("j" "u")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "ڪ" "" "" "" "" "" "" "" "" "" ""))
    ((("j" "u" "a" "n")) ("" "" "" "" "" "" "" "" "" "" "" "۲" "" "" ""))
    ((("j" "u" "e")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "ާ" ""))
    ((("j" "u" "n")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("k" "a")) ("" "" "" "" "" ""))
    ((("k" "a" "i")) ("" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("k" "a" "n")) ("" "" "٩" "" "" "" "" "" "" "" "" "ݨ" ""))
    ((("k" "a" "n" "g")) ("" "" "" "" "" "" "" "" "" ""))
    ((("k" "a" "o")) ("" "" "" "" "" "" "" ""))
    ((("k" "e")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("k" "e" "n")) ("" "" "" "" "" ""))
    ((("k" "e" "n" "g")) ("" "" ""))
    ((("k" "o" "n" "g")) ("" "" "" "" "" "" ""))
    ((("k" "o" "u")) ("" "" "" "" "ߵ" "ޢ" "" "" ""))
    ((("k" "u")) ("" "" "" "" "" "" "" "" "" "ܥ" "" ""))
    ((("k" "u" "a")) ("" "" "" "" "" "٨"))
    ((("k" "u" "a" "i")) ("" "" "" "" "" "" "" "" "" "" "ۦ"))
    ((("k" "u" "a" "n")) ("" "" ""))
    ((("k" "u" "a" "n" "g")) ("" "" "" "" "" "" "" "" "" "" "ڲ" "" "ڿ" "" "" ""))
    ((("k" "u" "i")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "ظ" "" "" "" "" "" "" "" "" "" "" ""))
    ((("k" "u" "n")) ("" "" "" "" "" "" "" "" "" "" ""))
    ((("k" "u" "o")) ("" "" "" "" "" ""))
    ((("l" "a")) ("" "" "" "" "" "" "" "" "" "" "" ""))
    ((("l" "a" "i")) ("" "" "" "" "" "" "" "" "" "" "" "")) 
    ((("l" "a" "n")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("l" "a" "n" "g")) ("" "" "" "" "" "" "" "" "" "ݹ" "" "" "" ""))
    ((("l" "a" "o")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("l" "e")) ("" "" "" "" "߷" "" "" ""))
    ((("l" "e" "i")) ("" "" "" "" "" "" "" "" "" "" "" "ڳ" "" "" "" "" "" "" ""))
    ((("l" "e" "n" "g")) ("" "" "" "" "ܨ"))
    ((("l" "i")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "ݰ" "" "" "ٵ" "" "޼" "ٳ" "" "" "۪" "" "" "" "" "" "" "" "" "" "" "" "" "ت" "" "" "" "" "" "޺" "߿" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("l" "i" "a")) ("")) 
    ((("l" "i" "a" "n")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("l" "i" "a" "n" "g")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "ݹ" "ܮ" "" "" ""))
    ((("l" "i" "a" "o")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "ޤ" ""))
    ((("l" "i" "e")) ("" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("l" "i" "n")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("l" "i" "n" "g")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "۹" "" "" ""))
    ((("l" "i" "u")) ("" "" "" "½" "" "" "" "µ" "" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("l" "o" "n" "g")) ("" "¡" "" "" "£" "" "" "¢" "" "" "¤" "" "" "" "" "" ""))
    ((("l" "o" "u")) ("¥" "ª" "©" "§" "" "¨" "" "¦" "" "" "" "" "" "" ""))
    ((("l" "u")) ("·" "½" "¼" "¬" "¶" "³" "¯" "¹" "µ" "®" "«" "" "­" "»" "" "±" "²" "´" "" "¸" "" "¾" "" "" "" "°" "º" "" "ߣ" "" "" "" "ޤ" "" "" "" "" "" "" "" "" ""))
    ((("l" "v")) ("" "" "" "" "" "" "" "" "" "¿" "" "" "" "" "" "" "" "" "" ""))
    ((("l" "u" "a" "n")) ("" "" "" "" "" "" "" "" "" "" ""))
    ((("l" "u" "e")) ("" "" ""))
    ((("l" "u" "n")) ("" "" "" "" "" "" "" ""))
    ((("l" "u" "o")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("m")) ("߼"))
    ((("m" "a")) ("" "" "" "" "" "" "" "Ĩ" "" "" "" "" "" "" ""))
    ((("m" "a" "i")) ("" "" "" "" "" "" "" "۽" "ݤ"))
    ((("m" "a" "n")) ("" "" "" "" "" "" "" "" "" "á" "ܬ" "" "" "" "" "" "" ""))
    ((("m" "a" "n" "g")) ("æ" "ã" "ä" "â" "å" "ç" "" "" "" ""))
    ((("m" "a" "o")) ("ë" "ð" "è" "ó" "ì" "ñ" "ò" "é" "ï" "" "î" "" "" "ê" "" "" "í" "" "" "" "" "" "" "" "" ""))
    ((("m" "e")) ("ô" ""))
    ((("m" "e" "i")) ("û" "" "ÿ" "" "ü" "÷" "ý" "ö" "" "ú" "" "ù" "õ" "" "" "" "" "ø" "ݮ" "" "" "" "" "" "" "" "þ"))
    ((("m" "e" "n")) ("" "" "" "" "" "" ""))
    ((("m" "e" "n" "g")) ("" "" "" "" "" "" "" "" "" "" "" "ޫ" "" "" "" "" "" "" ""))
    ((("m" "i")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("m" "i" "a" "n")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("m" "i" "a" "o")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("m" "i" "e")) ("" "" "" "" "ؿ" ""))
    ((("m" "i" "n")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("m" "i" "n" "g")) ("" "" "" "" "" "ڤ" "" "" "" "" "" ""))
    ((("m" "i" "u")) ("" ""))
    ((("m" "o")) ("Ĭ" "Ī" "ģ" "" "ĩ" "ĥ" "" "Ħ" "į" "Į" "ī" "Ĩ" "ħ" "İ" "" "ĭ" "Ĥ" "" "Ģ" "" "" "ġ" "" "" "" "" "" "" "" "" "" ""))
    ((("m" "o" "u")) ("ĳ" "ı" "" "" "" "" "ٰ" ""))
    ((("m" "u")) ("Ŀ" "ĸ" "ľ" "Ļ" "ķ" "Ľ" "" "Ĺ" "ļ" "ĺ" "Ĳ" "Ķ" "" "" "Ĵ" "" "ĵ" "" "" "" "" ""))
    ((("n")) ("" ""))
    ((("n" "a")) ("" "" "" "" "" "" "" "" "" "" "" "")) ((("n" "a" "i")) ("" "" "" "" "" "ܵ" "ؾ" "٦" "" ""))
    ((("n" "a" "n")) ("" "" "" "" "" "" "" "" "" ""))
    ((("n" "a" "n" "g")) ("" "" "" "߭" ""))
    ((("n" "a" "o")) ("" "" "" "" "" "" "" "" "" "ث" "" "" ""))
    ((("n" "e")) ("" "ګ"))
    ((("n" "e" "i")) ("" ""))
    ((("n" "e" "n")) ("" ""))
    ((("n" "e" "n" "g")) (""))
    ((("n" "g")) ("" ""))
    ((("n" "i")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "٣" "" "" ""))
    ((("n" "i" "a" "n")) ("" "" "إ" "ճ" "" "" "" "" "" "" "" "" "" ""))
    ((("n" "i" "a" "n" "g")) ("" ""))
    ((("n" "i" "a" "o")) ("" "" "" "" "" ""))
    ((("n" "i" "e")) ("" "" "" "" "" "" "" "" "" "ؿ" "" "" "" ""))
    ((("n" "i" "n")) ("" ""))
    ((("n" "i" "n" "g")) ("" "" "š" "Ţ" "" "" "" "" "" "" ""))
    ((("n" "i" "u")) ("ţ" "Ŧ" "Ť" "" "ť" "" "" ""))
    ((("n" "o" "n" "g")) ("ũ" "Ū" "Ũ" "ٯ" "" "ŧ"))
    ((("n" "o" "u")) (""))
    ((("n" "u")) ("ŭ" "Ŭ" "ū" "" "" "" ""))
    ((("n" "v")) ("Ů" "" "" ""))
    ((("n" "u" "a" "n")) ("ů"))
    ((("n" "u" "e")) ("Ű" "ű"))
    ((("n" "u" "o")) ("ŵ" "Ų" "ų" "Ŵ" "" "" "" ""))
    ((("o")) ("Ŷ" "" ""))
    ((("o" "u")) ("ŷ" "ż" "Ź" "Ż" "Ÿ" "ک" "" "ź" "Ž" "" ""))
    ((("p" "a")) ("" "" "" "" "ſ" "ž" "" "" "" "" "" "")) ((("p" "a" "i")) ("" "" "" "" "" "" "ٽ" "" ""))
    ((("p" "a" "n")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("p" "a" "n" "g")) ("" "" "" "" "" "" "" "" "" "" ""))
    ((("p" "a" "o")) ("" "" "" "" "" "" "" "" "" "" "" ""))
    ((("p" "e" "i")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("p" "e" "n")) ("" "" ""))
    ((("p" "e" "n" "g")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "ܡ" "" "" ""))
    ((("p" "i")) ("" "" "Ƥ" "ƨ" "" "ƣ" "" "ơ" "Ƣ" "ƥ" "Ƨ" "" "Ʃ" "" "Ʀ" "" "" "" "" "" "" "ۯ" "" "" "ا" "ܱ" "" "" "" "" "" "" "" "" "" "ߨ" "" "" "" "" "" "" "" "" "" "" ""))
    ((("p" "i" "a" "n")) ("" "Ƭ" "ƪ" "ƫ" "ƭ" "" "" "" "" "" "" "" ""))
    ((("p" "i" "a" "o")) ("Ʊ" "Ư" "Ʈ" "ư" "" "" "" "" "" "" "" "ݳ" ""))
    ((("p" "i" "e")) ("Ʋ" "Ƴ" "" "د" ""))
    ((("p" "i" "n")) ("Ʒ" "ƶ" "ƴ" "Ƶ" "Ƹ" "" "" "" "" "" ""))
    ((("p" "i" "n" "g")) ("ƽ" "" "ƿ" "ƾ" "Ƽ" "ƹ" "" "ƻ" "ƺ" "" "" "ٷ" ""))
    ((("p" "o")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "۶" ""))
    ((("p" "o" "u")) ("" "" ""))
    ((("p" "u")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("q" "i")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "ؽ" "" "" "" "" "" "ٹ" "" "" "" "" "" "" "ܻ" "" "" "" "" "ݽ" "" "" "" "" "" "ޭ" "" "" "" "" "" "" ""))
    ((("q" "i" "a")) ("ǡ" "Ǣ" "" "٤" "" "" ""))
    ((("q" "i" "a" "n")) ("ǰ" "Ǯ" "ǧ" "ǩ" "Ƿ" "ǣ" "ǳ" "Ǳ" "Ǩ" "ǫ" "ǲ" "Ǹ" "" "Ƕ" "Ǭ" "Ǵ" "Ǧ" "" "ǯ" "" "ٻ" "ǵ" "ǭ" "" "" "ܷ" "" "" "ݡ" "" "" "" "" "" "" "ǥ" "Ǫ" "" "" "" "" "" "Ǥ" "" ""))
    ((("q" "i" "a" "n" "g")) ("ǹ" "ǽ" "" "ǻ" "Ǻ" "" "" "Ǽ" "Ǿ" "" "" "" "" "" "" "" "" "" ""))
    ((("q" "i" "a" "o")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "ڽ" "" "" "" "" "" "" "" ""))
    ((("q" "i" "e")) ("" "" "" "" "" "" "" "" "" "٤" "" "" "ۧ" "" ""))
    ((("q" "i" "n")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("q" "i" "n" "g")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("q" "i" "o" "n" "g")) ("" "" "" "" "" "" "" "" ""))
    ((("q" "i" "u")) ("" "" "" "" "" "" "" "" "" "ٴ" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("q" "u")) ("ȥ" "ȡ" "" "" "Ȥ" "" "" "" "" "" "Ȣ" "" "" "" "" "" "" "" "" "" "" "" "" "" "ڰ" "" "۾" "ޡ" "޾" "ȣ" "" "" "" "" ""))
    ((("q" "u" "a" "n")) ("ȫ" "Ȩ" "Ȧ" "Ȱ" "Ȫ" "ȯ" "ȭ" "Ȯ" "ڹ" "ȧ" "" "" "" "" "Ȭ" "" "" "" "" "ȩ" ""))
    ((("q" "u" "e")) ("ȴ" "ȷ" "ȱ" "ȸ" "ȳ" "ȶ" "ȵ" "" "" "Ȳ" ""))
    ((("q" "u" "n")) ("Ⱥ" "ȹ" "" ""))
    ((("r" "a" "n")) ("Ȼ" "Ⱦ" "ȼ" "Ƚ" "" "" "")) ((("r" "a" "n" "g")) ("" "" "" "" "ȿ" "" "")) ((("r" "a" "o")) ("" "" "" "" "" "")) ((("r" "e")) ("" "" "")) ((("r" "e" "n")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "")) ((("r" "e" "n" "g")) ("" ""))
    ((("r" "i")) (""))
    ((("r" "o" "n" "g")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("r" "o" "u")) ("" "" "" "" "" ""))
    ((("r" "u")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "޸" "" "" "" ""))
    ((("r" "u" "a" "n")) ("" "" ""))
    ((("r" "u" "i")) ("" "" "" "" "ި" "" "" ""))
    ((("r" "u" "n")) ("" ""))
    ((("r" "u" "o")) ("" "" "ټ" ""))
    ((("s" "a")) ("" "" "" "ئ" "" "" "" ""))
    ((("s" "a" "i")) ("" "" "" "" ""))
    ((("s" "a" "n")) ("" "ɢ" "ɡ" "" "" "" "" "")) 
    ((("s" "a" "n" "g")) ("ɥ" "ɣ" "ɤ" "" "" ""))
    ((("s" "a" "o")) ("ɨ" "ɧ" "ɩ" "" "" "ɦ" "" "" "" "ܣ" ""))
    ((("s" "e")) ("ɫ" "" "ɬ" "ɪ" "" "" ""))
    ((("s" "e" "n")) ("ɭ"))
    ((("s" "e" "n" "g")) ("ɮ"))
    ((("s" "h" "a")) ("ɱ" "ɳ" "ɶ" "ɵ" "" "ɲ" "ɴ" "ɯ" "ɷ" "ɰ" "" "" "" "" "" "" "" "" ""))
    ((("s" "h" "a" "i")) ("ɹ" "ɸ" ""))
    ((("s" "h" "a" "n")) ("ɽ" "" "" "" "ɾ" "ɿ" "" "" "ɺ" "ɼ" "" "" "" "դ" "ڨ" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "۷" "" "ɻ" "" "" "" ""))
    ((("s" "h" "a" "n" "g")) ("" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("s" "h" "a" "o")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "ۿ" "" "" "" "" ""))
    ((("s" "h" "e")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("s" "h" "e" "i")) ("˭"))
    ((("s" "h" "e" "n")) ("ʲ" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "ݷ" "" "" "" "" "" "ڷ" "" "" "" "" "" ""))
    ((("s" "h" "e" "n" "g")) ("" "" "ʡ" "ʤ" "" "ʥ" "ʢ" "ʣ" "" "" "" "" "" "" "" ""))
    ((("s" "h" "i")) ("" "ʱ" "ʮ" "" "ʵ" "ʹ" "" "" "ʶ" "ʼ" "ʿ" "ʦ" "ʫ" "ʽ" "ʧ" "ʷ" "" "ʾ" "ʳ" "" "" "" "ʯ" "" "ʩ" "" "" "ʻ" "" "ʬ" "ʰ" "" "ʪ" "" "ʨ" "" "ʴ" "" "ʺ" "" "" "" "" "" "" "" "ʸ" "" "" "ʭ" "߱" "" "" "ݪ" "" "" "" "" "" "" "" "" "" "" ""))
    ((("s" "h" "o" "u")) ("" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("s" "h" "u")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "ˡ" "" "" "" "" "" "" "" "" "" "ٿ" "" "" "" "" "" "" "" "" "" "" "" "ح" "" "" ""))
    ((("s" "h" "u" "a")) ("ˢ" "ˣ" ""))
    ((("s" "h" "u" "a" "i")) ("" "˥" "ˤ" "˦" "˧" ""))
    ((("s" "h" "u" "a" "n")) ("" "˨" "˩" ""))
    ((("s" "h" "u" "a" "n" "g")) ("˫" "ˬ" "˪" "" ""))
    ((("s" "h" "u" "i")) ("ˮ" "˭" "˰" "˯"))
    ((("s" "h" "u" "n")) ("˳" "˴" "˲" "˱"))
    ((("s" "h" "u" "o")) ("˵" "˷" "˶" "˸" "" "" "" "" ""))
    ((("s" "i")) ("" "" "˼" "˹" "˾" "" "˽" "˿" "" "˺" "" "" "˻" "" "" "" "" "" "" "" "ٹ" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("s" "o" "n" "g")) ("" "" "" "" "" "" "" "" "" "" "" "ݿ" "" "" "ڡ" ""))
    ((("s" "o" "u")) ("" "" "" "" "" "޴" "" "" "" "" "" "" "" ""))
    ((("s" "u")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("s" "u" "a" "n")) ("" "" "" ""))
    ((("s" "u" "i")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "ݴ" "" "" "" ""))
    ((("s" "u" "n")) ("" "" "" "ݥ" "" "" "" ""))
    ((("s" "u" "o")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("t" "a")) ("" "" "" "̤" "" "" "" "" "̣" "" "" "̢" "" "" "" "" "" "" "̡"))
    ((("t" "a" "i")) ("̫" "̨" "̬" "̩" "̧" "̥" "̭" "̦" "߾" "" "ۢ" "޷" "̪" "" "" "" "" ""))
    ((("t" "a" "n")) ("̸" "̽" "" "̹" "̾" "̳" "̯" "̰" "̲" "̺" "̷" "̶" "̱" "̿" "" "̵" "" "̮" "̻" "̼" "" "̴" "" "" "۰" "" ""))
    ((("t" "a" "n" "g")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("t" "a" "o")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "ػ"))
    ((("t" "e")) ("" "" "߯" "" ""))
    ((("t" "e" "i")) ("߯"))
    ((("t" "e" "n" "g")) ("" "" "" "" ""))
    ((("t" "i")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("t" "i" "a" "n")) ("" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("t" "i" "a" "o")) ("" "" "" "" "" "" "" "٬" "" "" "" "" "" "" "" ""))
    ((("t" "i" "e")) ("" "" "" "" ""))
    ((("t" "i" "n" "g")) ("" "ͣ" "ͥ" "" "ͦ" "ͤ" "" "͢" "ͧ" "" "" "͡" "" "" "" "" "" ""))
    ((("t" "o" "n" "g")) ("ͬ" "ͨ" "ͳ" "ʹ" "ͯ" "ͮ" "Ͳ" "ͭ" "Ͱ" "ͱ" "ͩ" "ͫ" "١" "" "ͪ" "" "" "" "" "" "" "" "" ""))
    ((("t" "o" "u")) ("ͷ" "Ͷ" "͵" "͸" "" ""))
    ((("t" "u")) ("" "ͻ" "ͼ" ";" "ͽ" "" "Ϳ" "" "" "ͺ" "͹" "ݱ" "" "" "" "ܢ"))
    ((("t" "u" "a" "n")) ("" "" "" "" ""))
    ((("t" "u" "i")) ("" "" "" "" "" "" "߯" ""))
    ((("t" "u" "n")) ("" "" "" "" "" "" "" "" ""))
    ((("t" "u" "o")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "ر" "" "" "٢" "" "" "" "" "" ""))
    ((("w" "a")) ("" "" "" "" "" "" "" "" "" "" ""))
    ((("w" "a" "i")) ("" "" ""))
    ((("w" "a" "n")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "ݸ" "" "" "" "" "" "" "" "" "ܹ" "" ""))
    ((("w" "a" "n" "g")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("w" "e" "i")) ("Ϊ" "λ" "δ" "ί" "ά" "ζ" "Χ" "" "" "΢" "ΰ" "ν" "Ψ" "Σ" "ο" "β" "Υ" "κ" "" "ε" "α" "η" "θ" "ι" "" "Τ" "Ω" "Ρ" "γ" "ή" "" "έ" "ξ" "" "μ" "" "" "ޱ" "" "" "" "" "" "" "" "Φ" "Ϋ" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("w" "e" "n")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("w" "e" "n" "g")) ("" "" "" "" "޳"))
    ((("w" "o")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "ݫ" "" "" ""))
    ((("w" "u")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "أ" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("x" "i")) ("" "ϵ" "Ϣ" "ϣ" "ϲ" "ϯ" "ϰ" "ϸ" "Ϸ" "" "ϴ" "ϧ" "ϡ" "Ϥ" "" "Ϧ" "" "Ϯ" "" "" "" "Ϫ" "϶" "" "" "" "ϱ" "" "Ϩ" "ϥ" "ۭ" "Ϭ" "" "" "" "" "" "" "" "" "" "ϫ" "" "" "" "" "ϩ" "" "" "" "ϭ" "" "" "" "" "" "" "" "ϳ" "ݾ" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("x" "i" "a")) ("" "" "" "Ͽ" "" "" "" "ϼ" "Ϲ" "Ͼ" "Ϻ" "" "Ͻ" "" "ϻ" "" "" "" "" "" "" "" ""))
    ((("x" "i" "a" "n")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "ݲ" "" "" "" "ϳ" "" "" "" "" "޺" "" "" "" ""))
    ((("x" "i" "a" "n" "g")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "ܼ" "" ""))
    ((("x" "i" "a" "o")) ("С" "Ц" "У" "" "Ч" "" "" "" "Ф" "" "Т" "" "" "" "Х" "" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("x" "i" "e")) ("Щ" "д" "л" "Э" "Ь" "Я" "б" "й" "в" "Ъ" "г" "а" "е" "м" "ж" "Ю" "и" "к" "" "з" "" "" "" "ߢ" "Ш" "" "Ы" "" "" "ޯ" "" "" "" "" "" "" "" ""))
    ((("x" "i" "n")) ("" "" "" "" "" "н" "ܰ" "" "о" "" "" "" "п" "" "" "ض"))
    ((("x" "i" "n" "g")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "ߩ" "" "" "" ""))
    ((("x" "i" "o" "n" "g")) ("" "" "" "" "" "" "" "ܺ"))
    ((("x" "i" "u")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("x" "u")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "ڼ" "" "" "" "" "" "" "" "" "" "" "" "" "ޣ"))
    ((("x" "u" "a" "n")) ("ѡ" "" "" "" "ȯ" "" "" "" "" "" "Ѥ" "ѣ" "" "" "" "" "" "" "" "" "" "" "" "Ѣ" "" "" ""))
    ((("x" "u" "e")) ("ѧ" "Ѫ" "ѩ" "" "Ѩ" "" "ѥ" "Ѧ" "" "" "" ""))
    ((("x" "u" "n")) ("Ѱ" "ѯ" "ѵ" "Ѹ" "Ѷ" "Ѳ" "ѷ" "ѭ" "Ѯ" "Ѭ" "ѫ" "ѱ" "" "ѳ" "" "" "" "" "" "" "" "޹" "Ѵ" "ۨ" "" "" "" "" "" "" "ަ" ""))
    ((("y" "a")) ("" "ѹ" "" "" "ѽ" "Ѻ" "" "" "ѻ" "" "Ѽ" "" "Ѿ" "ѿ" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("y" "a" "n")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "ٲ" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "ܾ" "" "" "" "" "" "" "" "" "" "۱" "" "" "۳" "" "" "" "" "" ""))
    ((("y" "a" "n" "g")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("y" "a" "o")) ("Ҫ" "ҡ" "ҩ" "ҫ" "ң" "" "" "Ҧ" "ҧ" "Ң" "ҥ" "" "Ҥ" "ز" "" "" "ߺ" "Կ" "" "" "" "" "" "Ҩ" "" "" "س" "" "" "" "" "" ""))
    ((("y" "e")) ("Ҳ" "ҵ" "ҹ" "ү" "Ҷ" "Ұ" "ҳ" "Һ" "Ү" "" "ҷ" "ק" "" "ҭ" "" "ұ" "Ҭ" "Ҵ" "Ҹ" "" "" "" "" ""))
    ((("y" "i")) ("һ" "" "" "" "" "" "ҽ" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "߮" "ܲ" "߽" "" "" "Ҿ" "" "" "" "޲" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "٫" "" "ڱ" "" "" "Ҽ" "" "" "" "" "" "" "" "ҿ" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("y" "i" "n")) ("" "" "" "ӡ" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "ط" "۴" "" "" "" "" "" "" "" "ܧ" "" "" "" ""))
    ((("y" "i" "n" "g")) ("Ӧ" "Ӣ" "Ӱ" "Ӫ" "ӭ" "Ӳ" "ӳ" "Ӯ" "ӯ" "ӱ" "ӥ" "Ӥ" "Ӭ" "ӣ" "Ө" "ӫ" "" "ө" "" "ݺ" "" "" "" "ӧ" "" "" "" "" "" "" "" "" "" "۫" "" "" "" "" ""))
    ((("y" "o")) ("Ӵ" ""))
    ((("y" "o" "n" "g")) ("" "" "ӵ" "" "ӿ" "ӻ" "Ӿ" "ӹ" "Ӷ" "ӽ" "ٸ" "Ӻ" "" "" "ӷ" "" "" "Ӹ" "" "" "" "" "ܭ" "Ӽ" "")) ((("y" "o" "u")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "ݬ" "" "" "" "" "" "" "" "" "" "" "" "" "" "ݯ" "٧" "ݵ" "" "" ""))
    ((("y" "u")) ("" "" "" "" "" "" "" "" "" "" "Ԥ" "" "" "" "" "" "" "" "" "Ԣ" "ԥ" "" "" "" "" "" "" "" "ԣ" "" "" "ԡ" "" "" "" "" "" "" "" "" "" "Ԧ" "" "" "" "" "" "" "" "ع" "" "خ" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "ٶ" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("y" "u" "a" "n")) ("Ա" "Ԫ" "ԭ" "Ժ" "Զ" "Ը" "԰" "Դ" "Բ" "Թ" "Ե" "Ԯ" "ԩ" "Ԭ" "Ԩ" "Է" "Գ" "ԧ" "ԯ" "ԫ" "" "" "" "ܾ" "" "" "" "" "" "" "" "ܫ" "" "" ""))
    ((("y" "u" "e")) ("" "" "Խ" "Լ" "" "Ծ" "Ի" "" "" "" "Կ" "" "" "" "" "" ""))
    ((("y" "u" "n")) ("" "" "" "" "" "" "" "" "" "" "ܿ" "" "" "" "" "" "" "" "" "۩" "" "" "" ""))
    ((("z" "a")) ("" "" "" "զ" "" "" ""))
    ((("z" "a" "i")) ("" "" "" "" "" "" "" "" "" ""))
    ((("z" "a" "n")) ("" "" "" "" "" "" "" "" "" "" ""))
    ((("z" "a" "n" "g")) ("" "" "" "" "" "" "" ""))
    ((("z" "a" "o")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("z" "e")) ("" "" "" "" "զ" "" "" "" "" "" "" "" "" ""))
    ((("z" "e" "i")) (""))
    ((("z" "e" "n")) ("" ""))
    ((("z" "e" "n" "g")) ("" "" "" "" "" "" ""))
    ((("z" "h" "a")) ("ը" "" "զ" "թ" "է" "գ" "" "" "դ" "" "բ" "ե" "" "" "" "" "" "߸" "ա" "" "" "" "" ""))
    ((("z" "h" "a" "i")) ("ժ" "ծ" "լ" "խ" "ի" "կ" "" "" ""))
    ((("z" "h" "a" "n")) ("ս" "չ" "վ" "ռ" "մ" "ն" "շ" "ճ" "յ" "ո" "հ" "" "պ" "տ" "ղ" "ձ" "ջ" "" "" ""))
    ((("z" "h" "a" "n" "g")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "۵" "" "" "" ""))
    ((("z" "h" "a" "o")) ("" "" "" "" "" "" "" "" "" "" "" "" "گ" "" "" "" ""))
    ((("z" "h" "e")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "ߡ" "" "" ""))
    ((("z" "h" "e" "n")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("z" "h" "e" "n" "g")) ("" "" "֤" "" "" "" "" "֣" "֢" "" "" "" "" "" "" "" "" "" "ں" "" "" "֡"))
    ((("z" "h" "i")) ("֮" "ֻ" "֪" "" "" "ֱ" "" "ָ" "֧" "־" "ְ" "" "ֵ" "֯" "ֽ" "ֹ" "" "ִ" "" "" "ַ" "֦" "" "ֲ" "ּ" "" "" "" "" "ֿ" "֭" "" "ֳ" "֥" "֨" "֫" "֬" "" "ֶ" "" "֩" "ֺ" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "ش" "" "" "" "ۤ" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("z" "h" "o" "n" "g")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "ڣ" "" "" "")) 
    ((("z" "h" "o" "u")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "ݧ" "" "" ""))
    ((("z" "h" "u")) ("" "ס" "ע" "" "" "" "" "" "פ" "" "ף" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "٪" "" "" "ۥ" ""))
    ((("z" "h" "u" "a")) ("ץ" "צ"))
    ((("z" "h" "u" "a" "i")) ("ק" ""))
    ((("z" "h" "u" "a" "n")) ("" "ר" "ת" "׬" "׫" "ש" "׭" "" "" ""))
    ((("z" "h" "u" "a" "n" "g")) ("װ" "״" "׳" "ׯ" "ײ" "ױ" "" "׮" "" "" ""))
    ((("z" "h" "u" "i")) ("׷" "׹" "׺" "׶" "׸" "" "׵" "" "" ""))
    ((("z" "h" "u" "n")) ("׼" "׻" "" ""))
    ((("z" "h" "u" "o")) ("" "" "׽" "׿" "" "" "" "׾" "" "" "" "" "" "" "" "" "" "پ" "" "" "ߪ"))
    ((("z" "i")) ("" "" "" "" "" "" "" "" "" "֨" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    ((("z" "o" "n" "g")) ("" "" "" "" "" "" "" "" "" "" ""))
    ((("z" "o" "u")) ("" "" "" "" "" "" "" "" "۸")) 
    ((("z" "u")) ("" "" "" "" "" "" "" "" "" "" ""))
    ((("z" "u" "a" "n")) ("׬" "" "߬" "" "" ""))
    ((("z" "u" "i")) ("" "" "" "" "" "" "ީ"))
    ((("z" "u" "n")) ("" "" "" "" "ߤ"))
    ((("z" "u" "o")) ("" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" "" ""))
    (((",")) (""))
    (((".")) (""))
    ((("?")) (""))
    ((("!")) (""))
    ((("\"")) (""))
    ((("#")) (""))
    ((("$")) (""))
    ((("%")) (""))
    ((("&")) (""))
    ((("'")) (""))
    ((("(")) (""))
    (((")")) (""))
    ((("=")) (""))
    ((("^")) (""))
    ((("\\")) (""))
    ((("|")) (""))
    ((("`")) (""))
    ((("@")) (""))
    ((("+")) (""))
    (((";")) (""))
    ((("*")) (""))
    (((":")) (""))
    ((("}")) (""))
    ((("<")) (""))
    (((">")) (""))
    ((("/")) (""))
    ((("_")) (""))
  ))
